@@ -23,7 +23,7 @@ at the top-level directory.
  * and the preconditioned GMRES is applied to the equilibrated system.
  * The driver routine CGSISX is called twice to perform factorization
  * and apply preconditioner separately.
- *
+ * 
  * Note that CGSISX performs the following factorization:
  *     Pr*Dr*A*Dc*Pc^T ~= LU
  * with Pr being obtained from MC64 statically then partial pivoting
@@ -34,7 +34,7 @@ at the top-level directory.
  * Then GMRES step requires requires 2 procedures:
  *   1) Apply preconditioner M^{-1} = Pc^T*U^{-1}*L^{-1}*Pr
  *   2) Matrix-vector multiplication: w = A1*v
- *
+ * 
  * \ingroup Example
  */
 
@@ -56,10 +56,7 @@ mem_usage_t   *GLOBAL_MEM_USAGE;
  * \param [out] x    Solution
  * \param [in,out] y Right-hand side
  */
-void cpsolve(int n,
-                  complex x[], /* solution */
-                  complex y[]  /* right-hand side */
-)
+void cpsolve(int n, singlecomplex x[], singlecomplex y[])
 {
     SuperMatrix *A = GLOBAL_A, *L = GLOBAL_L, *U = GLOBAL_U;
     SuperLUStat_t *stat = GLOBAL_STAT;
@@ -89,6 +86,7 @@ void cpsolve(int n,
 #endif
 }
 
+
 /*!
  * \brief Performs matrix-vector multipliation sp_cgemv with original matrix A.
  *
@@ -101,7 +99,7 @@ void cpsolve(int n,
  * \param [in,out] y Vector to add to to matrix-vector multiplication and
  *                   storage for result.
  */
-void cmatvec_mult(complex alpha, complex x[], complex beta, complex y[])
+void cmatvec_mult(singlecomplex alpha, singlecomplex x[], singlecomplex beta, singlecomplex y[])
 {
     SuperMatrix *A = GLOBAL_A;
 
@@ -110,12 +108,12 @@ void cmatvec_mult(complex alpha, complex x[], complex beta, complex y[])
 
 int main(int argc, char *argv[])
 {
-    void cmatvec_mult(complex alpha, complex x[], complex beta, complex y[]);
-    void cpsolve(int n, complex x[], complex y[]);
+    void cmatvec_mult(singlecomplex alpha, singlecomplex x[], singlecomplex beta, singlecomplex y[]);
+    void cpsolve(int n, singlecomplex x[], singlecomplex y[]);
     extern int cfgmr( int n,
-	void (*matvec_mult)(complex, complex [], complex, complex []),
-	void (*psolve)(int n, complex [], complex[]),
-	complex *rhs, complex *sol, double tol, int restrt, int *itmax,
+	void (*matvec_mult)(singlecomplex, singlecomplex [], singlecomplex, singlecomplex []),
+	void (*psolve)(int n, singlecomplex [], singlecomplex[]),
+	singlecomplex *rhs, singlecomplex *sol, double tol, int restrt, int *itmax,
 	FILE *fits);
     extern int cfill_diag(int n, NCformat *Astore);
 
@@ -128,26 +126,26 @@ int main(int argc, char *argv[])
     SCformat *Lstore;
     GlobalLU_t	   Glu; /* facilitate multiple factorizations with 
                            SamePattern_SameRowPerm                  */
-    complex   *a;
+    singlecomplex   *a;
     int_t    *asub, *xa;
     int      *etree;
     int      *perm_c; /* column permutation vector */
     int      *perm_r; /* row permutations from partial pivoting */
     int      nrhs, ldx, m, n;
     int_t    info, nnz, lwork;
-    complex   *rhsb, *rhsx, *xact;
-    complex   *work = NULL;
+    singlecomplex   *rhsb, *rhsx, *xact;
+    singlecomplex   *work = NULL;
     float   *R, *C;
     float   rpg, rcond;
-    complex zero = {0.0, 0.0};
-    complex one = {1.0, 0.0};
-    complex none = {-1.0, 0.0};
+    singlecomplex zero = {0.0, 0.0};
+    singlecomplex one = {1.0, 0.0};
+    singlecomplex none = {-1.0, 0.0};
     mem_usage_t   mem_usage;
     superlu_options_t options;
     SuperLUStat_t stat;
     FILE 	  *fp = stdin;
 
-    complex *x, *b;
+    singlecomplex *x, *b;
 
 #ifdef DEBUG
     extern int num_drop_L, num_drop_U;
@@ -223,7 +221,7 @@ int main(int argc, char *argv[])
 		break;
 	    default:
 		printf("Unrecognized format.\n");
-                return EXIT_FAILURE;
+		return EXIT_FAILURE;
 	}
     }
 
@@ -235,11 +233,11 @@ int main(int argc, char *argv[])
     fflush(stdout);
 
     /* Generate the right-hand side */
-    if ( !(rhsb = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb[].");
-    if ( !(rhsx = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsx[].");
+    if ( !(rhsb = singlecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb[].");
+    if ( !(rhsx = singlecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsx[].");
     cCreate_Dense_Matrix(&B, m, nrhs, rhsb, m, SLU_DN, SLU_C, SLU_GE);
     cCreate_Dense_Matrix(&X, m, nrhs, rhsx, m, SLU_DN, SLU_C, SLU_GE);
-    xact = complexMalloc(n * nrhs);
+    xact = singlecomplexMalloc(n * nrhs);
     ldx = n;
     cGenXtrue(n, nrhs, xact, ldx);
     cFillRHS(trans, nrhs, xact, ldx, &A, &B);
@@ -268,13 +266,11 @@ int main(int argc, char *argv[])
 	   lwork, &B, &X, &rpg, &rcond, &Glu, &mem_usage, &stat, &info);
 
     /* Set RHS for GMRES. */
-    if (!(b = complexMalloc(m))) ABORT("Malloc fails for b[].");
+    if (!(b = singlecomplexMalloc(m))) ABORT("Malloc fails for b[].");
     if (*equed == 'R' || *equed == 'B') {
-        for (int i = 0; i < n; ++i)
-            cs_mult(&b[i], &rhsb[i], R[i]);
+	for (int i = 0; i < n; ++i) cs_mult(&b[i], &rhsb[i], R[i]);
     } else {
-        for (int i = 0; i < m; i++)
-            b[i] = rhsb[i];
+	for (int i = 0; i < m; i++) b[i] = rhsb[i];
     }
 
     printf("cgsisx(): info %lld, equed %c\n", (long long)info, equed[0]);
@@ -325,19 +321,18 @@ int main(int argc, char *argv[])
     int maxit = 1000;
     int iter = maxit;
     double resid = 1e-4;
-    if (!(x = complexMalloc(n))) ABORT("Malloc fails for x[].");
+    if (!(x = singlecomplexMalloc(n))) ABORT("Malloc fails for x[].");
 
     if (info <= n + 1)
     {
 	int i_1 = 1, nnz32;
 	double maxferr = 0.0, nrmA, nrmB, res, t;
-        complex temp;
-	extern float scnrm2_(int *, complex [], int *);
-	extern void caxpy_(int *, complex *, complex [], int *, complex [], int *);
+        singlecomplex temp;
+	extern float scnrm2_(int *, singlecomplex [], int *);
+	extern void caxpy_(int *, singlecomplex *, singlecomplex [], int *, singlecomplex [], int *);
 
-        /* Initial guess */
-        for (int i = 0; i < n; i++)
-            x[i] = zero;
+	/* Initial guess */
+	for (int i = 0; i < n; i++) x[i] = zero;
 
 	t = SuperLU_timer_();
 
@@ -348,7 +343,7 @@ int main(int argc, char *argv[])
 
 	/* Output the result. */
 	nnz32 = Astore->nnz;
-	nrmA = scnrm2_(&nnz32, (complex *)((DNformat *)A.Store)->nzval,
+	nrmA = scnrm2_(&nnz32, (singlecomplex *)((NCformat *)A.Store)->nzval,
 		&i_1);
 	nrmB = scnrm2_(&m, b, &i_1);
 	sp_cgemv("N", none, &A, x, 1, one, b, 1);
@@ -367,10 +362,9 @@ int main(int argc, char *argv[])
 
 	/* Scale the solution back if equilibration was performed. */
 	if (*equed == 'C' || *equed == 'B') 
-            for (int i = 0; i < n; i++)
-                cs_mult(&x[i], &x[i], C[i]);
+	    for (int i = 0; i < n; i++) cs_mult(&x[i], &x[i], C[i]);
 
-        for (int i = 0; i < m; i++) {
+	for (int i = 0; i < m; i++) {
             c_sub(&temp, &x[i], &xact[i]);
             maxferr = SUPERLU_MAX(maxferr, c_abs1(&temp));
         }
