@@ -18,24 +18,28 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
-
+ 
 /*! \file
- * \brief CGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A.
+ * \brief @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A.
  *
  * \ingroup Example
  */
-
+ 
 #include <getopt.h>
 #include "slu_cdefs.h"
 
+void parse_command_line(int argc, char *argv[], int *lwork,
+                        float *u, yes_no_t *equil, trans_t *trans);
+
 /*!
- * \brief The driver program CLINSOLX2.
+ * \brief The driver program CLINSOLX3.
  *
  * This example illustrates how to use CGSSVX to solve systems repeatedly
  * with the same sparsity pattern and similar values of matrix A.
  * In this case, the permutation vectors perm_r and perm_c are computed once.
  * The following data structures will be reused in the subsequent call to
  * CGSSVX: perm_r, perm_c, etree, L, U.
+ * 
  */
 int main(int argc, char *argv[])
 {
@@ -48,15 +52,15 @@ int main(int argc, char *argv[])
     NCformat       *Ustore;
     SCformat       *Lstore;
     GlobalLU_t 	   Glu;
-    complex         *a, *a1;
+    singlecomplex         *a, *a1;
     int_t          *asub, *xa, *asub1, *xa1;
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            m, n, nrhs, ldx;
     int_t          info, lwork, nnz;
-    complex         *rhsb, *rhsb1, *rhsx, *xact;
+    singlecomplex         *rhsb, *rhsb1, *rhsx, *xact;
     float         *R, *C;
     float         *ferr, *berr;
     float         u, rpg, rcond;
@@ -65,8 +69,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE 	   *fp = stdin;
 
-    extern void    parse_command_line();
-
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Enter main()");
 #endif
@@ -107,32 +109,30 @@ int main(int argc, char *argv[])
 
     /* Read matrix A from a file in Harwell-Boeing format.*/
     creadhb(fp, &m, &n, &nnz, &a, &asub, &xa);
-    if ( !(a1 = complexMalloc(nnz)) ) ABORT("Malloc fails for a1[].");
+    if ( !(a1 = singlecomplexMalloc(nnz)) ) ABORT("Malloc fails for a1[].");
     if ( !(asub1 = intMalloc(nnz)) ) ABORT("Malloc fails for asub1[].");
     if ( !(xa1 = intMalloc(n+1)) ) ABORT("Malloc fails for xa1[].");
     for (int i = 0; i < nnz; ++i) {
         a1[i] = a[i];
 	asub1[i] = asub[i];
     }
-    for (int i = 0; i < n+1; ++i)
-        xa1[i] = xa[i];
+    for (int i = 0; i < n+1; ++i) xa1[i] = xa[i];
     
     cCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_C, SLU_GE);
     Astore = A.Store;
     printf("Dimension %dx%d; # nonzeros %d\n", (int)A.nrow, (int)A.ncol, (int)Astore->nnz);
     
-    if ( !(rhsb = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb[].");
-    if ( !(rhsb1 = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb1[].");
-    if ( !(rhsx = complexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsx[].");
+    if ( !(rhsb = singlecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb[].");
+    if ( !(rhsb1 = singlecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsb1[].");
+    if ( !(rhsx = singlecomplexMalloc(m * nrhs)) ) ABORT("Malloc fails for rhsx[].");
     cCreate_Dense_Matrix(&B, m, nrhs, rhsb, m, SLU_DN, SLU_C, SLU_GE);
     cCreate_Dense_Matrix(&X, m, nrhs, rhsx, m, SLU_DN, SLU_C, SLU_GE);
-    xact = complexMalloc(n * nrhs);
+    xact = singlecomplexMalloc(n * nrhs);
     ldx = n;
     cGenXtrue(n, nrhs, xact, ldx);
     cFillRHS(trans, nrhs, xact, ldx, &A, &B);
     for (int j = 0; j < nrhs; ++j)
-        for (int i = 0; i < m; ++i)
-            rhsb1[i+j*m] = rhsb[i+j*m];
+        for (int i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
     
     if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
     if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
@@ -161,7 +161,7 @@ int main(int argc, char *argv[])
     if ( info == 0 || info == n+1 ) {
 
         /* This is how you could access the solution matrix. */
-        complex *sol = (complex*) ((DNformat*) X.Store)->nzval; 
+        singlecomplex *sol = (singlecomplex*) ((DNformat*) X.Store)->nzval; 
         (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
@@ -179,7 +179,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -213,7 +213,7 @@ int main(int argc, char *argv[])
     if ( info == 0 || info == n+1 ) {
 
         /* This is how you could access the solution matrix. */
-        complex *sol = (complex*) ((DNformat*) X.Store)->nzval; 
+        singlecomplex *sol = (singlecomplex*) ((DNformat*) X.Store)->nzval; 
         (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
@@ -229,7 +229,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -261,15 +261,16 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+
     return EXIT_SUCCESS;
 }
 
-/*!
- * \brief Parse command line options to get relaxed snode size, panel size, etc.
+/*  
+ * Parse command line options to get relaxed snode size, panel size, etc.
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
-                   double *u, yes_no_t *equil, trans_t *trans )
+                   float *u, yes_no_t *equil, trans_t *trans )
 {
     int c;
     extern char *optarg;
