@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -9,14 +9,15 @@ The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
 */
 
-/*! @file ditersol1.c
- * \brief Example #2 showing how to use ILU to precondition GMRES
- *
- * <pre>
+/*
  * -- SuperLU routine (version 5.0) --
  * Lawrence Berkeley National Laboratory
  * November, 2010
  * August, 2011
+ */
+
+/*! \file
+ * \brief Example #2 showing how to use ILU to precondition GMRES
  *
  * This example shows that ILU is computed from the equilibrated matrix,
  * but the preconditioned GMRES is applied to the original system.
@@ -34,10 +35,9 @@ at the top-level directory.
  *   1) Apply preconditioner M^{-1} = Dc*Pc^T*U^{-1}*L^{-1}*Pr*Dr
  *   2) Matrix-vector multiplication: w = A*v
  *
- * </pre>
+ * \ingroup Example
  */
 
-#include <unistd.h>
 #include "slu_ddefs.h"
 
 char *GLOBAL_EQUED;
@@ -48,10 +48,16 @@ SuperMatrix *GLOBAL_A, *GLOBAL_A_ORIG, *GLOBAL_L, *GLOBAL_U;
 SuperLUStat_t *GLOBAL_STAT;
 mem_usage_t   *GLOBAL_MEM_USAGE;
 
-void dpsolve(int n,
-                  double x[], /* solution */
-                  double y[]  /* right-hand side */
-)
+/*!
+ * \brief Performs DGSISX with original matrix A.
+ *
+ * See documentation of dgsisx for more details.
+ *
+ * \param [in] n     Dimension of matrices
+ * \param [out] x    Solution
+ * \param [in,out] y Right-hand side
+ */
+void dpsolve(int n, double x[], double y[])
 {
     SuperMatrix *A = GLOBAL_A, *L = GLOBAL_L, *U = GLOBAL_U;
     SuperLUStat_t *stat = GLOBAL_STAT;
@@ -81,6 +87,18 @@ void dpsolve(int n,
 #endif
 }
 
+/*!
+ * \brief Performs matrix-vector multipliation sp_dgemv with original matrix A.
+ *
+ * The operations is y := alpha*A*x + beta*y. See documentation of sp_dgemv
+ * for further details.
+ *
+ * \param [in] alpha Scalar factor for A*x
+ * \param [in] x Vector to multiply with A
+ * \param [in] beta Scalar factor for y
+ * \param [in,out] y Vector to add to to matrix-vector multiplication and
+ *                   storage for result.
+ */
 void dmatvec_mult(double alpha, double x[], double beta, double y[])
 {
     SuperMatrix *A = GLOBAL_A_ORIG;
@@ -100,7 +118,6 @@ int main(int argc, char *argv[])
     extern int dfill_diag(int n, NCformat *Astore);
 
     char     equed[1] = {'B'};
-    yes_no_t equil;
     trans_t  trans;
     SuperMatrix A, AA, L, U;
     SuperMatrix B, X;
@@ -119,16 +136,13 @@ int main(int argc, char *argv[])
     double   *rhsb, *rhsx, *xact;
     double   *work = NULL;
     double   *R, *C;
-    double   u, rpg, rcond;
+    double   rpg, rcond;
     double zero = 0.0;
-    double one = 1.0;
     mem_usage_t   mem_usage;
     superlu_options_t options;
     SuperLUStat_t stat;
     FILE    *fp = stdin;
 
-    int restrt, iter, maxit, i;
-    double resid;
     double *x, *b;
 
 #ifdef DEBUG
@@ -182,7 +196,7 @@ int main(int argc, char *argv[])
 		"-r -rb:\n\t[INPUT] is a Rutherford-Boeing format matrix.\n"
 		"-t -triplet:\n\t[INPUT] is a triplet format matrix.\n",
 		argv[0]);
-	return 0;
+        return EXIT_FAILURE;
     }
     else
     {
@@ -205,7 +219,7 @@ int main(int argc, char *argv[])
 		break;
 	    default:
 		printf("Unrecognized format.\n");
-		return 0;
+		return EXIT_FAILURE;
 	}
     }
 
@@ -221,11 +235,11 @@ int main(int argc, char *argv[])
     a_orig = doubleMalloc(nnz);
     asub_orig = intMalloc(nnz);
     xa_orig = intMalloc(n+1);
-    for (i = 0; i < nnz; ++i) {
+    for (int i = 0; i < nnz; ++i) {
 	a_orig[i] = ((double *)Astore->nzval)[i];
 	asub_orig[i] = Astore->rowind[i];
     }
-    for (i = 0; i <= n; ++i) xa_orig[i] = Astore->colptr[i];
+    for (int i = 0; i <= n; ++i) xa_orig[i] = Astore->colptr[i];
     dCreate_CompCol_Matrix(&AA, m, n, nnz, a_orig, asub_orig, xa_orig,
 			   SLU_NC, SLU_D, SLU_GE);
     
@@ -264,7 +278,7 @@ int main(int argc, char *argv[])
 
     /* Set RHS for GMRES. */
     if (!(b = doubleMalloc(m))) ABORT("Malloc fails for b[].");
-    for (i = 0; i < m; i++) b[i] = rhsb[i];
+    for (int i = 0; i < m; i++) b[i] = rhsb[i];
 
     printf("dgsisx(): info %lld, equed %c\n", (long long)info, equed[0]);
     if (info > 0 || rcond < 1e-8 || rpg > 1e8)
@@ -312,22 +326,21 @@ int main(int argc, char *argv[])
     options.ConditionNumber = NO;
 
     /* Set the variables used by GMRES. */
-    restrt = SUPERLU_MIN(n / 3 + 1, 50);
-    maxit = 1000;
-    iter = maxit;
-    resid = 1e-8;
+    int restrt = SUPERLU_MIN(n / 3 + 1, 50);
+    int maxit = 1000;
+    int iter = maxit;
+    double resid = 1e-8;
     if (!(x = doubleMalloc(n))) ABORT("Malloc fails for x[].");
 
     if (info <= n + 1)
     {
 	int i_1 = 1;
 	double maxferr = 0.0, nrmA, nrmB, res, t;
-        double temp;
 	extern double dnrm2_(int *, double [], int *);
 	extern void daxpy_(int *, double *, double [], int *, double [], int *);
 
 	/* Initial guess */
-	for (i = 0; i < n; i++) x[i] = zero;
+	for (int i = 0; i < n; i++) x[i] = zero;
 
 	t = SuperLU_timer_();
 
@@ -338,7 +351,7 @@ int main(int argc, char *argv[])
 
 	/* Output the result. */
 	int nnz32 = Astore->nnz;
-	nrmA = dnrm2_(&nnz32, (double *)((DNformat *)A.Store)->nzval,
+	nrmA = dnrm2_(&nnz32, (double *)((NCformat *)A.Store)->nzval,
 		&i_1);
 	nrmB = dnrm2_(&m, b, &i_1);
 	sp_dgemv("N", -1.0, &A, x, 1, 1.0, b, 1);
@@ -355,7 +368,7 @@ int main(int argc, char *argv[])
 	printf("iteration: %d\nresidual: %.1e\nGMRES time: %.2f seconds.\n",
 		iter, resid, t);
 
-	for (i = 0; i < m; i++) {
+	for (int i = 0; i < m; i++) {
 	    maxferr = SUPERLU_MAX(maxferr, fabs(x[i] - xact[i]));
         }
 	printf("||X-X_true||_oo = %.1e\n", maxferr);
@@ -392,5 +405,5 @@ int main(int argc, char *argv[])
     CHECK_MALLOC("Exit main()");
 #endif
 
-    return 0;
+    return EXIT_SUCCESS;
 }
