@@ -18,16 +18,20 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
-
+ 
 /*! \file
- * \brief DGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A.
+ * \brief SGSSVX to solve systems repeatedly with the same sparsity pattern of matrix A.
  *
  * \ingroup Example
  */
-
 #include <getopt.h>
 #include "slu_sdefs.h"
 
+void parse_command_line(int argc, char *argv[], int *lwork,
+                        float *u, yes_no_t *equil, trans_t *trans);
+			
+int main(int argc, char *argv[])
+{
 /*!
  * \brief The driver program SLINSOLX2.
  *
@@ -36,9 +40,8 @@ at the top-level directory.
  * In this case, the column permutation vector perm_c is computed once.
  * The following data structures will be reused in the subsequent call to
  * SGSSVX: perm_c, etree
+ * 
  */
-int main(int argc, char *argv[])
-{
     char           equed[1];
     yes_no_t       equil;
     trans_t        trans;
@@ -54,7 +57,7 @@ int main(int argc, char *argv[])
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            m, n, nrhs, ldx;
     int_t          info, lwork, nnz;
     float         *rhsb, *rhsb1, *rhsx, *xact;
@@ -66,8 +69,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE 	   *fp = stdin;
 
-    extern void    parse_command_line();
-
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Enter main()");
 #endif
@@ -115,8 +116,7 @@ int main(int argc, char *argv[])
         a1[i] = a[i];
 	asub1[i] = asub[i];
     }
-    for (int i = 0; i < n+1; ++i)
-        xa1[i] = xa[i];
+    for (int i = 0; i < n+1; ++i) xa1[i] = xa[i];
     
     sCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_S, SLU_GE);
     Astore = A.Store;
@@ -132,8 +132,7 @@ int main(int argc, char *argv[])
     sGenXtrue(n, nrhs, xact, ldx);
     sFillRHS(trans, nrhs, xact, ldx, &A, &B);
     for (int j = 0; j < nrhs; ++j)
-        for (int i = 0; i < m; ++i)
-            rhsb1[i+j*m] = rhsb[i+j*m];
+        for (int i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
     
     if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
     if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
@@ -180,7 +179,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -234,7 +233,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -274,7 +273,7 @@ int main(int argc, char *argv[])
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
-                   double *u, yes_no_t *equil, trans_t *trans )
+                   float *u, yes_no_t *equil, trans_t *trans )
 {
     int c;
     extern char *optarg;
