@@ -1,5 +1,4 @@
-
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -19,16 +18,21 @@ at the top-level directory.
  * Last update: July 10, 2015
  *
  */
-#include <unistd.h>
+ 
+/*! \file
+ * \brief @(PREE)GSSVX to solve systems repeatedly with the same sparsity pattern and similar values of matrix A.
+ *
+ * \ingroup Example
+ */
+ 
+#include <getopt.h>
 #include "slu_sdefs.h"
 
-int main(int argc, char *argv[])
-{
-/*
- * Purpose
- * =======
- *
- * The driver program SLINSOLX2.
+void parse_command_line(int argc, char *argv[], int *lwork,
+                        float *u, yes_no_t *equil, trans_t *trans);
+
+/*!
+ * \brief The driver program SLINSOLX3.
  *
  * This example illustrates how to use SGSSVX to solve systems repeatedly
  * with the same sparsity pattern and similar values of matrix A.
@@ -37,6 +41,8 @@ int main(int argc, char *argv[])
  * SGSSVX: perm_r, perm_c, etree, L, U.
  * 
  */
+int main(int argc, char *argv[])
+{
     char           equed[1];
     yes_no_t       equil;
     trans_t        trans;
@@ -51,9 +57,9 @@ int main(int argc, char *argv[])
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            m, n, nrhs, ldx;
-    int_t          i, j, info, lwork, nnz;
+    int_t          info, lwork, nnz;
     float         *rhsb, *rhsb1, *rhsx, *xact;
     float         *R, *C;
     float         *ferr, *berr;
@@ -63,8 +69,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE 	   *fp = stdin;
 
-    extern void    parse_command_line();
-
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Enter main()");
 #endif
@@ -108,11 +112,11 @@ int main(int argc, char *argv[])
     if ( !(a1 = floatMalloc(nnz)) ) ABORT("Malloc fails for a1[].");
     if ( !(asub1 = intMalloc(nnz)) ) ABORT("Malloc fails for asub1[].");
     if ( !(xa1 = intMalloc(n+1)) ) ABORT("Malloc fails for xa1[].");
-    for (i = 0; i < nnz; ++i) {
+    for (int i = 0; i < nnz; ++i) {
         a1[i] = a[i];
 	asub1[i] = asub[i];
     }
-    for (i = 0; i < n+1; ++i) xa1[i] = xa[i];
+    for (int i = 0; i < n+1; ++i) xa1[i] = xa[i];
     
     sCreate_CompCol_Matrix(&A, m, n, nnz, a, asub, xa, SLU_NC, SLU_S, SLU_GE);
     Astore = A.Store;
@@ -127,8 +131,8 @@ int main(int argc, char *argv[])
     ldx = n;
     sGenXtrue(n, nrhs, xact, ldx);
     sFillRHS(trans, nrhs, xact, ldx, &A, &B);
-    for (j = 0; j < nrhs; ++j)
-        for (i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
+    for (int j = 0; j < nrhs; ++j)
+        for (int i = 0; i < m; ++i) rhsb1[i+j*m] = rhsb[i+j*m];
     
     if ( !(perm_c = int32Malloc(n)) ) ABORT("Malloc fails for perm_c[].");
     if ( !(perm_r = int32Malloc(m)) ) ABORT("Malloc fails for perm_r[].");
@@ -158,6 +162,7 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         float *sol = (float*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
 	if ( options.ConditionNumber )
@@ -174,7 +179,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -209,6 +214,7 @@ int main(int argc, char *argv[])
 
         /* This is how you could access the solution matrix. */
         float *sol = (float*) ((DNformat*) X.Store)->nzval; 
+        (void)sol;  // suppress unused variable warning
 
 	if ( options.PivotGrowth ) printf("Recip. pivot growth = %e\n", rpg);
 	if ( options.ConditionNumber )
@@ -223,7 +229,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-	    for (i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", (int)i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
@@ -255,6 +261,8 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+
+    return EXIT_SUCCESS;
 }
 
 /*  
@@ -262,7 +270,7 @@ int main(int argc, char *argv[])
  */
 void
 parse_command_line(int argc, char *argv[], int *lwork,
-                   double *u, yes_no_t *equil, trans_t *trans )
+                   float *u, yes_no_t *equil, trans_t *trans )
 {
     int c;
     extern char *optarg;
