@@ -18,7 +18,7 @@ at the top-level directory.
  */
 
 /*! \file
- * \brief  LU factorization from zgstrf (ZGSSVX)
+ * \brief LU factorization from ZGSTRF (ZGSSVX)
  *
  * \ingroup Example
  */
@@ -26,6 +26,9 @@ at the top-level directory.
 #include <getopt.h>
 #include "slu_zdefs.h"
 
+void parse_command_line(int argc, char *argv[], int *lwork,
+                        double *u, yes_no_t *equil, trans_t *trans);
+			
 int main(int argc, char *argv[])
 {
     char           equed[1];
@@ -43,7 +46,7 @@ int main(int argc, char *argv[])
     int            *perm_r; /* row permutations from partial pivoting */
     int            *perm_c; /* column permutation vector */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            nrhs, ldx;
     int_t          info, lwork, nnz;
     int            m, n;
@@ -56,8 +59,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE           *fp = stdin;
 
-    extern void  parse_command_line();
-
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Enter main()");
 #endif
@@ -155,7 +156,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine != NOREFINE ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
         Lstore = (SCformat *) L.Store;
@@ -200,6 +201,7 @@ int main(int argc, char *argv[])
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Exit main()");
 #endif
+
     return EXIT_SUCCESS;
 }
 
@@ -208,7 +210,7 @@ int main(int argc, char *argv[])
  * \brief Parse command line inputs.
  */
 void
-parse_command_line(int argc, char *argv[], int *lwork,
+parse_command_line(int argc, char *argv[], int_t *lwork,
                    double *u, yes_no_t *equil, trans_t *trans )
 {
     int c;
