@@ -28,6 +28,11 @@ at the top-level directory.
 #include <getopt.h>
 #include "slu_zdefs.h"
 
+void parse_command_line(int argc, char *argv[], int *lwork,
+                        double *u, yes_no_t *equil, trans_t *trans);
+			
+int main(int argc, char *argv[])
+{
 /*!
  * \brief The driver program ZLINSOLX1.
  *
@@ -36,9 +41,8 @@ at the top-level directory.
  * In this case, we factorize A only once in the first call to DGSSVX,
  * and reuse the following data structures in the subsequent call to ZGSSVX:
  *     perm_c, perm_r, R, C, L, U.
+ * 
  */
-int main(int argc, char *argv[])
-{
     char           equed[1];
     yes_no_t       equil;
     trans_t        trans;
@@ -54,7 +58,7 @@ int main(int argc, char *argv[])
     int            *perm_c; /* column permutation vector */
     int            *perm_r; /* row permutations from partial pivoting */
     int            *etree;
-    void           *work;
+    void           *work = NULL;
     int            m, n, nrhs, ldx;
     int_t          info, lwork, nnz;
     doublecomplex         *rhsb, *rhsx, *xact;
@@ -66,8 +70,6 @@ int main(int argc, char *argv[])
     SuperLUStat_t stat;
     FILE           *fp = stdin;
 
-    extern void    parse_command_line();
-
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC("Enter main()");
 #endif
@@ -192,7 +194,7 @@ int main(int argc, char *argv[])
 	if ( options.IterRefine ) {
             printf("Iterative Refinement:\n");
 	    printf("%8s%8s%16s%16s\n", "rhs", "Steps", "FERR", "BERR");
-            for (int i = 0; i < nrhs; ++i)
+	    for (int i = 0; i < nrhs; ++i)
 	      printf("%8d%8d%16e%16e\n", i+1, stat.RefineSteps, ferr[i], berr[i]);
 	}
 	fflush(stdout);
