@@ -13,9 +13,10 @@ at the top-level directory.
  * \brief Memory details
  *
  * <pre>
- * -- SuperLU routine (version 4.0) --
+ * -- SuperLU routine (version 7.0.0) --
  * Lawrence Berkeley National Laboratory.
  * June 30, 2009
+ * August 2024
  * </pre>
  */
 #include "slu_ddefs.h"
@@ -47,7 +48,7 @@ extern void    user_bcopy      (char *, char *, int);
 
 
 /*! \brief Setup the memory model to be used for factorization.
- *
+ *  
  *    lwork = 0: use system malloc;
  *    lwork > 0: use user-supplied work[] space.
  */
@@ -143,6 +144,7 @@ int dQuerySpace(SuperMatrix *L, SuperMatrix *U, mem_usage_t *mem_usage)
  *      The amount of space used in bytes for the L\\U data structures.
  *    - <tt>total_needed (float)</tt>
  *      The amount of space needed in bytes to perform factorization.
+ *
  */
 int ilu_dQuerySpace(SuperMatrix *L, SuperMatrix *U, mem_usage_t *mem_usage)
 {
@@ -332,7 +334,6 @@ dLUMemInit(fact_t fact, void *work, int_t lwork, int m, int n, int_t annz,
 } /* dLUMemInit */
 
 /*! \brief Allocate known working storage.
- *
  * Returns 0 if success, otherwise
  * returns the number of bytes allocated so far when failure occurred.
  */
@@ -370,7 +371,7 @@ dLUWorkInit(int m, int n, int panel_size, int **iworkptr,
 	    *dworkptr = (double*) ((double*)*dworkptr - 1);
 	    extra = (char*)old_ptr - (char*)*dworkptr;
 #if ( DEBUGlevel>=1 )
-	    printf("dLUWorkInit: not aligned, extra %d\n", extra);
+	    printf("dLUWorkInit: not aligned, extra %d\n", extra); fflush(stdout);
 #endif	    
 	    Glu->stack.top2 -= extra;
 	    Glu->stack.used += extra;
@@ -382,7 +383,7 @@ dLUWorkInit(int m, int n, int panel_size, int **iworkptr,
     }
 	
     return 0;
-}
+} /* end dLUWorkInit */
 
 
 /*! \brief Set up pointers for real working arrays.
@@ -436,7 +437,7 @@ dLUMemXpand(int jcol,
     void   *new_mem;
     
 #if ( DEBUGlevel>=1 ) 
-    printf("dLUMemXpand(): jcol %d, next %lld, maxlen %lld, MemType %d\n",
+    printf("dLUMemXpand[1]: jcol %d, next %lld, maxlen %lld, MemType %d\n",
 	   jcol, (long long) next, (long long) *maxlen, mem_type);
 #endif    
 
@@ -542,7 +543,9 @@ void
 	expanders[type].mem = (void *) new_mem;
 	
     } else { /* MemModel == USER */
-	if ( Glu->num_expansions == 0 ) {
+    
+	if ( Glu->num_expansions == 0 ) { /* First time initialization */
+	
 	    new_mem = duser_malloc(new_len * lword, HEAD, Glu);
 	    if ( NotDoubleAlign(new_mem) &&
 		(type == LUSUP || type == UCOL) ) {
@@ -555,8 +558,11 @@ void
 		Glu->stack.top1 += extra;
 		Glu->stack.used += extra;
 	    }
+	    
 	    expanders[type].mem = (void *) new_mem;
-	} else {
+	    
+	} else { /* CASE: num_expansions != 0 */
+	
 	    tries = 0;
 	    extra = (new_len - *prev_len) * lword;
 	    if ( keep_prev ) {
@@ -570,7 +576,11 @@ void
 		}
 	    }
 
-	    if ( type != USUB ) {
+	      /* Need to expand the memory: moving the content after the current MemType
+	      	 to make extra room for the current MemType.
+              	 Memory layout: [ LUSUP || UCOL || LSUB || USUB ]
+	      */
+  	    if ( type != USUB ) {
 		new_mem = (void*)((char*)expanders[type + 1].mem + extra);
 		bytes_to_copy = (char*)Glu->stack.array + Glu->stack.top1
 		    - (char*)expanders[type + 1].mem;
@@ -595,7 +605,7 @@ void
 		    Glu->stack.used += extra;
 		}
 		
-	    } /* if ... */
+	    } /* end expansion */
 
 	} /* else ... */
     }
