@@ -23,14 +23,14 @@ at the top-level directory.
 #include <stdlib.h>
 #include "slu_cdefs.h"
 
-extern void cswap_(int *, complex [], int *, complex [], int *);
-extern void caxpy_(int *, complex *, complex [], int *, complex [], int *);
-extern void ccopy_(int *, complex [], int *, complex [], int *);
+extern void cswap_(int *, singlecomplex [], int *, singlecomplex [], int *);
+extern void caxpy_(int *, singlecomplex *, singlecomplex [], int *, singlecomplex [], int *);
+extern void ccopy_(int *, singlecomplex [], int *, singlecomplex [], int *);
 extern void scopy_(int *, float [], int *, float [], int *);
-extern float scasum_(int *, complex *, int *);
-extern float scnrm2_(int *, complex *, int *);
+extern float scasum_(int *, singlecomplex *, int *);
+extern float scnrm2_(int *, singlecomplex *, int *);
 extern double dnrm2_(int *, double [], int *);
-extern int icamax_(int *, complex [], int *);
+extern int icamax_(int *, singlecomplex [], int *);
 
 #if 0
 static float *A;  /* used in _compare_ only */
@@ -77,7 +77,7 @@ int ilu_cdrop_row(
     int m, n; /* m x n is the size of the supernode */
     int r = 0; /* number of dropped rows */
     register float *temp;
-    register complex *lusup = (complex *) Glu->lusup;
+    register singlecomplex *lusup = (singlecomplex *) Glu->lusup;
     int_t *lsub = Glu->lsub;
     int_t *xlsub = Glu->xlsub;
     int_t *xlusup = Glu->xlusup;
@@ -85,8 +85,8 @@ int ilu_cdrop_row(
     int    drop_rule = options->ILU_DropRule;
     milu_t milu = options->ILU_MILU;
     norm_t nrm = options->ILU_Norm;
-    complex one = {1.0, 0.0};
-    complex none = {-1.0, 0.0};
+    singlecomplex one = {1.0, 0.0};
+    singlecomplex none = {-1.0, 0.0};
     int i_1 = 1;
     int inc_diag; /* inc_diag = m + 1 */
     int nzp = 0;  /* number of zero pivots */
@@ -271,7 +271,7 @@ int ilu_cdrop_row(
     if (milu != SILU)
     {
 	register int j;
-	complex t;
+	singlecomplex t;
 	float omega;
 	for (j = 0; j < n; j++)
 	{
