@@ -3,16 +3,16 @@
 #define SUPERLU_CONFIG_H
 
 /* Enable metis */
-/* #undef HAVE_METIS */
+#define HAVE_METIS TRUE
 
 /* Enable colamd */
 /* #undef HAVE_COLAMD */
 
 /* enable 64bit index mode */
-#define XSDK_INDEX_SIZE 64
+/* #undef XSDK_INDEX_SIZE */
 
 /* Integer type for indexing sparse matrix meta structure */
-#if (XSDK_INDEX_SIZE == 64)
+#if defined(XSDK_INDEX_SIZE) && (XSDK_INDEX_SIZE == 64)
 #include <stdint.h>
 #define _LONGINT 1
 typedef int64_t int_t;
