@@ -13,10 +13,11 @@ at the top-level directory.
  * \brief Computes an LU factorization of a general sparse matrix
  *
  * <pre>
- * -- SuperLU routine (version 3.0) --
+ * -- SuperLU routine (version 7.0.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * October 15, 2003
+ * August 2024
  * 
  * Copyright (c) 1994 by Xerox Corporation.  All rights reserved.
  *
@@ -408,16 +409,24 @@ zgstrf (superlu_options_t *options, SuperMatrix *A,
     } /* for */
 
     *info = iinfo;
-    
-    if ( m > n ) {
-	k = 0;
-        for (i = 0; i < m; ++i) 
-            if ( perm_r[i] == EMPTY ) {
-    		perm_r[i] = n + k;
-		++k;
-	    }
-    }
 
+    /* Complete perm_r[] for rank-deficient or tall-skinny matrices */
+    /* k is the rank of U
+       pivots have been completed for rows < k
+       Now fill in the pivots for rows k to m */
+    k = iinfo == 0 ? n : (int)iinfo - 1;
+    if (m > k) {
+        /* if k == m, then all the row permutations are complete and
+           we can short circuit looking through the rest of the vector */
+        for (i = 0; i < m && k < m; ++i) {
+            if (perm_r[i] == EMPTY) {
+                perm_r[i] = k;
+                ++k;
+            }
+
+        }
+    }
+    
     countnz(min_mn, xprune, &nnzL, &nnzU, Glu);
     fixupL(min_mn, perm_r, Glu);
 
