@@ -1,6 +1,6 @@
-#include "f2c.h"
+#include "../../SRC/slu_ddefs.h"
 
-/* Subroutine */ int dlaruv_slu(integer *iseed, integer *n, doublereal *x)
+/* Subroutine */ int dlaruv_slu(int *iseed, int *n, double *x)
 {
 /*  -- LAPACK auxiliary routine (version 2.0) --   
        Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,   
@@ -53,7 +53,7 @@
    Parameter adjustments   
        Function Body */
     /* Initialized data */
-    static integer mm[512]	/* was [128][4] */ = { 494,2637,255,2008,1253,
+    static int mm[512]	/* was [128][4] */ = { 494,2637,255,2008,1253,
 	    3344,4084,1739,3143,3468,688,1657,1238,3166,1292,3422,1270,2016,
 	    154,2862,697,1706,491,931,1444,444,3577,3944,2184,1661,3482,657,
 	    3023,3618,1267,1828,164,3798,3087,2400,2870,3876,1905,1593,1797,
@@ -94,7 +94,7 @@
 	    3537,517,3017,2141,1537 };
     /* System generated locals */
     /* Local variables */
-    static integer i, i1, i2, i3, i4, it1, it2, it3, it4;
+    static int i, i1, i2, i3, i4, it1, it2, it3, it4;
 
 
 #define MM(I) mm[(I)]
@@ -109,7 +109,7 @@
     i3 = ISEED(3);
     i4 = ISEED(4);
 
-    for (i = 1; i <= min(*n,128); ++i) {
+    for (i = 1; i <= SUPERLU_MIN(*n,128); ++i) {
 
 /*        Multiply the seed by i-th power of the multiplier modulo 2**
 48 */
@@ -127,13 +127,10 @@
 		i4 * MM(i - 1);
 	it1 %= 4096;
 
-/*        Convert 48-bit integer to a real number in the interval (0,1
-) */
-
-	X(i) = ((doublereal) it1 + ((doublereal) it2 + ((doublereal) it3 + (
-		doublereal) it4 * 2.44140625e-4) * 2.44140625e-4) * 
-		2.44140625e-4) * 2.44140625e-4;
-/* L10: */
+        // Convert 48-bit integer to a real number in the interval (0,1)
+        X(i) = ((double) it1 + ((double) it2 + ((double) it3
+               + (double) it4 * 2.44140625e-4) * 2.44140625e-4) * 2.44140625e-4)
+               * 2.44140625e-4;
     }
 
 /*     Return final value of seed */
