@@ -10,23 +10,23 @@ at the top-level directory.
 */
 
 /*
- * -- SuperLU routine (version 3.0) --
+ * -- SuperLU routine (version 7.0.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * October 15, 2003
+ * August 2024
  *
  */
 
 /*! \file
- * CDRIVE is the main test program for the COMPLEX linear
+ * CDRIVE is the main test program for the SINGLE COMPLEX linear 
  * equation driver routines CGSSV and CGSSVX.
- *
+ * 
  * The program is invoked by a shell script file -- ctest.csh.
  * The output from the tests are written into a file -- ctest.out.
  *
  * \ingroup TestingC
  */
-
 #include <getopt.h>
 #include <string.h>
 #include "slu_cdefs.h"
@@ -50,7 +50,7 @@ parse_command_line(int argc, char *argv[], char *matrix_type,
  */
 int main(int argc, char *argv[])
 {
-    complex         *a, *a_save;
+    singlecomplex         *a, *a_save;
     int_t          *asub, *asub_save;
     int_t          *xa, *xa_save;
     SuperMatrix  A, B, X, L, U;
@@ -60,17 +60,17 @@ int main(int argc, char *argv[])
     int            *perm_r; /* row permutation from partial pivoting */
     int            *perm_c, *pc_save; /* column permutation */
     int            *etree;
-    complex  zero = {0.0, 0.0};
+    singlecomplex  zero = {0.0, 0.0};
     float         *R, *C;
     float         *ferr, *berr;
     float         *rwork;
-    complex	   *wwork;
-    void           *work;
+    singlecomplex	   *wwork;
+    void           *work = NULL;
     int            nrhs, panel_size, relax;
     int            m, n, info1;
     int_t          nnz, lwork, info;
-    complex         *xact;
-    complex         *rhsb, *solx, *bsav;
+    singlecomplex         *xact;
+    singlecomplex         *rhsb, *solx, *bsav;
     int            ldb, ldx;
     float         rpg, rcond;
     int            i, j, k1;
@@ -79,11 +79,12 @@ int main(int argc, char *argv[])
     int            prefact, equil, iequed;
     int            nt, nrun, nfail, nerrs, imat, fimat, nimat;
     int            nfact, ifact, itran;
-    int            kl, ku, mode, lda;
-    int            zerot, izero, ioff;
+    int            kl, ku, mode, lda, ioff;
+    int            zerot; /* indicate whether the matrix is singular */
+    int            izero; /* incidate the first column that is entirely zero */
     double         u;
     float         anorm, cndnum;
-    complex         *Afull;
+    singlecomplex         *Afull;
     float         result[NTESTS];
     superlu_options_t options;
     fact_t         fact;
@@ -103,15 +104,20 @@ int main(int argc, char *argv[])
     /* Some function prototypes */ 
     extern int cgst01(int, int, SuperMatrix *, SuperMatrix *, 
 		      SuperMatrix *, int *, int *, float *);
-    extern int cgst02(trans_t, int, int, int, SuperMatrix *, complex *,
-                      int, complex *, int, float *resid);
-    extern int cgst04(int, int, complex *, int, 
-                      complex *, int, float rcond, float *resid);
-    extern int cgst07(trans_t, int, int, SuperMatrix *, complex *, int,
-                         complex *, int, complex *, int, 
+    extern int cgst02(trans_t, int, int, int, SuperMatrix *, singlecomplex *,
+                      int, singlecomplex *, int, float *resid);
+    extern int cgst04(int, int, singlecomplex *, int, 
+                      singlecomplex *, int, float rcond, float *resid);
+    extern int cgst07(trans_t, int, int, SuperMatrix *, singlecomplex *, int,
+                         singlecomplex *, int, singlecomplex *, int, 
                          float *, float *, float *);
-    extern int sp_cconvert(int, int, complex *, int, int, int,
-	                   complex *a, int_t *, int_t *, int_t *);
+    extern int clatb4_slu(char *, int *, int *, int *, char *, int *, int *, 
+	               float *, int *, float *, char *);
+    extern int clatms_slu(int *, int *, char *, int *, char *, float *d,
+                       int *, float *, float *, int *, int *,
+                       char *, singlecomplex *, int *, singlecomplex *, int *);
+    extern int sp_cconvert(int, int, singlecomplex *, int, int, int,
+	                   singlecomplex *a, int_t *, int_t *, int_t *);
 
 
     /* Executable statements */
@@ -155,7 +161,7 @@ int main(int argc, char *argv[])
 	nnz = n * n;        /* upper bound */
 	fimat = 1;
 	nimat = NTYPES;
-	Afull = complexCalloc(lda * n);
+	Afull = singlecomplexCalloc(lda * n);
 	callocateA(n, nnz, &a, &asub, &xa);
     } else {
 	/* Read a sparse matrix */
@@ -164,14 +170,16 @@ int main(int argc, char *argv[])
     }
 
     callocateA(n, nnz, &a_save, &asub_save, &xa_save);
-    rhsb = complexMalloc(m * nrhs);
-    bsav = complexMalloc(m * nrhs);
-    solx = complexMalloc(n * nrhs);
+    rhsb = singlecomplexMalloc(m * nrhs);
+    bsav = singlecomplexMalloc(m * nrhs);
+    solx = singlecomplexMalloc(n * nrhs);
+    xact = singlecomplexMalloc(n * nrhs);
+    wwork = singlecomplexCalloc( SUPERLU_MAX(m,n) * SUPERLU_MAX(4,nrhs) );
+
     ldb  = m;
     ldx  = n;
     cCreate_Dense_Matrix(&B, m, nrhs, rhsb, ldb, SLU_DN, SLU_C, SLU_GE);
     cCreate_Dense_Matrix(&X, n, nrhs, solx, ldx, SLU_DN, SLU_C, SLU_GE);
-    xact = complexMalloc(n * nrhs);
     etree   = int32Malloc(n);
     perm_r  = int32Malloc(n);
     perm_c  = int32Malloc(n);
@@ -188,7 +196,6 @@ int main(int argc, char *argv[])
     if ( !ferr ) ABORT("SUPERLU_MALLOC fails for ferr");
     if ( !berr ) ABORT("SUPERLU_MALLOC fails for berr");
     if ( !rwork ) ABORT("SUPERLU_MALLOC fails for rwork");
-    wwork   = complexCalloc( SUPERLU_MAX(m,n) * SUPERLU_MAX(4,nrhs) );
 
     for (i = 0; i < n; ++i) perm_c[i] = pc_save[i] = i;
     options.ColPerm = MY_PERMC;
@@ -231,14 +238,14 @@ int main(int argc, char *argv[])
 			    Afull[ioff + i + j*lda] = zero;
 		}
 	    } else {
-		izero = 0;
+		izero = n+1; /* none of the column is zero */
 	    }
 
 	    /* Convert to sparse representation. */
 	    sp_cconvert(n, n, Afull, lda, kl, ku, a, asub, xa, &nnz);
 
 	} else {
-	    izero = 0;
+	    izero = n+1; /* none of the column is zero */
 	    zerot = 0;
 	}
 	
@@ -354,12 +361,13 @@ int main(int argc, char *argv[])
                                 printf(FMT3, "cgssv",
 				       (int) info, izero, n, nrhs, imat, nfail);
 			    } else {
-                                /* Reconstruct matrix from factors and
-	                           compute residual. */
-                                cgst01(m, n, &A, &L, &U, perm_c, perm_r,
+                                /* Reconstruct matrix from factors and compute residual.
+				 * Only compute the leading 'izero' nonzero columns.
+				 */
+                                cgst01(m, izero-1, &A, &L, &U, perm_c, perm_r,
                                          &result[0]);
 				nt = 1;
-				if ( izero == 0 ) {
+				if ( izero == (n+1) ) {
 				    /* Compute residual of the computed
 				       solution. */
 				    cCopy_Dense_Matrix(m, nrhs, rhsb, ldb,
@@ -418,9 +426,10 @@ int main(int argc, char *argv[])
                             }
 			} else {
 			    if ( !prefact ) {
-			    	/* Reconstruct matrix from factors and
-	 			   compute residual. */
-                                cgst01(m, n, &A, &L, &U, perm_c, perm_r,
+			    	/* Reconstruct matrix from factors and compute residual.
+				 * Only compute the leading 'izero' nonzero columns.
+				 */
+                                cgst01(m, izero-1, &A, &L, &U, perm_c, perm_r,
                                          &result[0]);
 				k1 = 0;
 			    } else {
@@ -513,8 +522,8 @@ int main(int argc, char *argv[])
 	Destroy_SuperMatrix_Store(&U);
     }
 
-    return 0;
-}
+    return (nfail == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+} /* end main */
 
 /*!
  * Parse command line options to get relaxed snode size, panel size, etc.
