@@ -10,11 +10,11 @@ at the top-level directory.
 */
 
 /*
- * -- SuperLU routine (version 2.0) --
+ * -- SuperLU routine (version 7.0.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * November 15, 1997
- *
+ * August 2024
  */
 
 /*! \file
@@ -23,9 +23,8 @@ at the top-level directory.
  *     norm(L*U - A) / ( N * norm(A) * EPS ),
  *  where EPS is the machine epsilon.
  *
- * \ingroup TestingC
+ * \ingroup	TestingC
  */
-
 #include <math.h>
 #include "slu_cdefs.h"
 
@@ -35,30 +34,30 @@ at the top-level directory.
  *    norm(L*U - A) / ( N * norm(A) * EPS ),
  * where EPS is the machine epsilon.
  *
- * \param[in] m The number of rows of the matrix A.  M >= 0.
- * \param[in] n The number of columns of the matrix A.  N >= 0.
- * \param[in] A The original M x N matrix A.
- * \param[in] L The factor matrix L, dimension (L->nrow, L->ncol).
- * \param[in] U The factor matrix U, dimension (U->nrow, U->ncol).
- * \param[in] perm_c The column permutation from CGSTRF, dimension (N).
- * \param[in] perm_r The pivot indices from CGSTRF, dimension (M).
- * \param[out] resid norm(L*U - A) / ( N * norm(A) * EPS )
+ * \param[in] m       The number of rows of the matrix A.  M >= 0.
+ * \param[in] n       The number of columns of the matrix A.  N >= 0.
+ * \param[in] A       The original M x N matrix A.
+ * \param[in] L       The factor matrix L, dimension(L->nrow, L->ncol).
+ * \param[in] U       The factor matrix U, dimension(U->nrow, U->ncol).
+ * \param[in] perm_c  The column permutation from CGSTRF, dimension(N).
+ * \param[in] perm_r  The pivot indices from CGSTRF, dimension(M).
+ * \param[out] resid  norm(L*U - A) / ( N * norm(A) * EPS )
  */
 int cgst01(int m, int n, SuperMatrix *A, SuperMatrix *L, 
-           SuperMatrix *U, int *perm_c, int *perm_r, float *resid)
+		SuperMatrix *U, int *perm_c, int *perm_r, float *resid)
 {
     /* Local variables */
-    complex zero = {0.0, 0.0};
+    singlecomplex zero = {0.0, 0.0};
     int i, j, k, arow, superno, fsupc, u_part;
     int_t urow, lptr, isub;
-    complex utemp;
-    complex comp_temp;
+    singlecomplex utemp;
+    singlecomplex comp_temp;
     float anorm, tnorm, cnorm;
     float eps;
-    complex *work;
+    singlecomplex *work;
     SCformat *Lstore;
     NCformat *Astore, *Ustore;
-    complex *Aval, *Lval, *Uval;
+    singlecomplex *Aval, *Lval, *Uval;
     int_t *colbeg, *colend;
 
     /* Function prototypes */
@@ -71,7 +70,7 @@ int cgst01(int m, int n, SuperMatrix *A, SuperMatrix *L,
 	return 0;
     }
 
-    work = (complex *)complexCalloc(m);
+    work = (singlecomplex *)singlecomplexCalloc(m);
 
     Astore = A->Store;
     Aval = Astore->nzval;
