@@ -10,17 +10,18 @@ at the top-level directory.
 */
 
 /*
- * -- SuperLU routine (version 3.0) --
+ * -- SuperLU routine (version 7.0.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * October 15, 2003
+ * August 2024
  *
  */
 
 /*! \file
- * DDRIVE is the main test program for the DOUBLE linear
+ * DDRIVE is the main test program for the DOUBLE linear 
  * equation driver routines DGSSV and DGSSVX.
- *
+ * 
  * The program is invoked by a shell script file -- dtest.csh.
  * The output from the tests are written into a file -- dtest.out.
  *
@@ -64,7 +65,7 @@ int main(int argc, char *argv[])
     double         *ferr, *berr;
     double         *rwork;
     double	   *wwork;
-    void           *work;
+    void           *work = NULL;
     int            nrhs, panel_size, relax;
     int            m, n, info1;
     int_t          nnz, lwork, info;
@@ -78,8 +79,9 @@ int main(int argc, char *argv[])
     int            prefact, equil, iequed;
     int            nt, nrun, nfail, nerrs, imat, fimat, nimat;
     int            nfact, ifact, itran;
-    int            kl, ku, mode, lda;
-    int            zerot, izero, ioff;
+    int            kl, ku, mode, lda, ioff;
+    int            zerot; /* indicate whether the matrix is singular */
+    int            izero; /* incidate the first column that is entirely zero */
     double         u;
     double         anorm, cndnum;
     double         *Afull;
@@ -109,6 +111,11 @@ int main(int argc, char *argv[])
     extern int dgst07(trans_t, int, int, SuperMatrix *, double *, int,
                          double *, int, double *, int, 
                          double *, double *, double *);
+    extern int dlatb4_slu(char *, int *, int *, int *, char *, int *, int *, 
+	               double *, int *, double *, char *);
+    extern int dlatms_slu(int *, int *, char *, int *, char *, double *d,
+                       int *, double *, double *, int *, int *,
+                       char *, double *, int *, double *, int *);
     extern int sp_dconvert(int, int, double *, int, int, int,
 	                   double *a, int_t *, int_t *, int_t *);
 
@@ -166,11 +173,13 @@ int main(int argc, char *argv[])
     rhsb = doubleMalloc(m * nrhs);
     bsav = doubleMalloc(m * nrhs);
     solx = doubleMalloc(n * nrhs);
+    xact = doubleMalloc(n * nrhs);
+    wwork = doubleCalloc( SUPERLU_MAX(m,n) * SUPERLU_MAX(4,nrhs) );
+
     ldb  = m;
     ldx  = n;
     dCreate_Dense_Matrix(&B, m, nrhs, rhsb, ldb, SLU_DN, SLU_D, SLU_GE);
     dCreate_Dense_Matrix(&X, n, nrhs, solx, ldx, SLU_DN, SLU_D, SLU_GE);
-    xact = doubleMalloc(n * nrhs);
     etree   = int32Malloc(n);
     perm_r  = int32Malloc(n);
     perm_c  = int32Malloc(n);
@@ -187,7 +196,6 @@ int main(int argc, char *argv[])
     if ( !ferr ) ABORT("SUPERLU_MALLOC fails for ferr");
     if ( !berr ) ABORT("SUPERLU_MALLOC fails for berr");
     if ( !rwork ) ABORT("SUPERLU_MALLOC fails for rwork");
-    wwork   = doubleCalloc( SUPERLU_MAX(m,n) * SUPERLU_MAX(4,nrhs) );
 
     for (i = 0; i < n; ++i) perm_c[i] = pc_save[i] = i;
     options.ColPerm = MY_PERMC;
@@ -230,14 +238,14 @@ int main(int argc, char *argv[])
 			    Afull[ioff + i + j*lda] = zero;
 		}
 	    } else {
-		izero = 0;
+		izero = n+1; /* none of the column is zero */
 	    }
 
 	    /* Convert to sparse representation. */
 	    sp_dconvert(n, n, Afull, lda, kl, ku, a, asub, xa, &nnz);
 
 	} else {
-	    izero = 0;
+	    izero = n+1; /* none of the column is zero */
 	    zerot = 0;
 	}
 	
@@ -353,12 +361,13 @@ int main(int argc, char *argv[])
                                 printf(FMT3, "dgssv",
 				       (int) info, izero, n, nrhs, imat, nfail);
 			    } else {
-                                /* Reconstruct matrix from factors and
-	                           compute residual. */
-                                dgst01(m, n, &A, &L, &U, perm_c, perm_r,
+                                /* Reconstruct matrix from factors and compute residual.
+				 * Only compute the leading 'izero' nonzero columns.
+				 */
+                                dgst01(m, izero-1, &A, &L, &U, perm_c, perm_r,
                                          &result[0]);
 				nt = 1;
-				if ( izero == 0 ) {
+				if ( izero == (n+1) ) {
 				    /* Compute residual of the computed
 				       solution. */
 				    dCopy_Dense_Matrix(m, nrhs, rhsb, ldb,
@@ -417,9 +426,10 @@ int main(int argc, char *argv[])
                             }
 			} else {
 			    if ( !prefact ) {
-			    	/* Reconstruct matrix from factors and
-	 			   compute residual. */
-                                dgst01(m, n, &A, &L, &U, perm_c, perm_r,
+			    	/* Reconstruct matrix from factors and compute residual.
+				 * Only compute the leading 'izero' nonzero columns.
+				 */
+                                dgst01(m, izero-1, &A, &L, &U, perm_c, perm_r,
                                          &result[0]);
 				k1 = 0;
 			    } else {
@@ -512,8 +522,8 @@ int main(int argc, char *argv[])
 	Destroy_SuperMatrix_Store(&U);
     }
 
-    return 0;
-}
+    return (nfail == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
+} /* end main */
 
 /*!
  * Parse command line options to get relaxed snode size, panel size, etc.
